==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_results/mp0078_001/MP0078_GetTaskDefault_001_Result.java <==

package net.datastream.schemas.mp_results.mp0078_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0078_001}ResultData"/>
 *       &lt;/sequence>
 *       &lt;attribute name="multiorg" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0078_GetTaskDefault_001_Result")
public class MP0078_GetTaskDefault_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected ResultData resultData;
    @XmlAttribute(name = "multiorg")
    protected String multiorg;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link ResultData }
     *     
     */
    public ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link ResultData }
     *     
     */
    public void setResultData(ResultData value) {
        this.resultData = value;
    }

    /**
     * Obtient la valeur de la propriété multiorg.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMultiorg() {
        if (multiorg == null) {
            return "false";
        } else {
            return multiorg;
        }
    }

    /**
     * Définit la valeur de la propriété multiorg.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMultiorg(String value) {
        this.multiorg = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_results/mp0078_001/MP0078_GetTaskDefault_001_Result.java <==

package net.datastream.schemas.mp_results.mp0078_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0078_001}ResultData"/>
 *       &lt;/sequence>
 *       &lt;attribute name="multiorg" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0078_GetTaskDefault_001_Result")
public class MP0078_GetTaskDefault_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected ResultData resultData;
    @XmlAttribute(name = "multiorg")
    protected String multiorg;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link ResultData }
     *     
     */
    public ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link ResultData }
     *     
     */
    public void setResultData(ResultData value) {
        this.resultData = value;
    }

    /**
     * Gets the value of the multiorg property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMultiorg() {
        if (multiorg == null) {
            return "false";
        } else {
            return multiorg;
        }
    }

    /**
     * Sets the value of the multiorg property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMultiorg(String value) {
        this.multiorg = value;
    }

}
